@@ -32,7 +32,7 @@ class APIHandler:
         self._headers = headers
         self.__logging = logging
         self._timeout = timeout
-        
+
         self.connection_exceptions = (
             ConnectionError,
             ProxyError,
@@ -46,9 +46,7 @@ class APIHandler:
     def host(self):
         return self._host
 
-    def send_request(
-        self, method, url, payload=None, log_config: dict = None, headers: dict = None
-    ):
+    def send_request(self, method, url, payload=None, log_config: dict = None, headers: dict = None):
         if not headers:
             headers = self._headers
 
@@ -75,7 +73,7 @@ class APIHandler:
                     request_headers=headers,
                     request_body=payload,
                     request_time=log_config["timezone"].now(),
-                    package_name=log_config.get("package_name")
+                    package_name=log_config.get("package_name"),
                 )
 
             response = requests.request(
@@ -84,6 +82,7 @@ class APIHandler:
                 headers=headers,
                 timeout=self._timeout,
                 data=payload,
+                verify=False,
             )
 
             if self.__logging:
@@ -127,13 +126,14 @@ class APIHandler:
 
             if log_entry:
                 from datetime import datetime
+
                 log_entry.response_code = 408
                 log_entry.response_body = str(excp)
                 log_entry.response_time = datetime.now()
                 log_entry.save()
 
             exception_message = f"Exception while connecting to WKFS. Error: {excp}"
-            
+
         except HTTPError as excp:
             if self.__logging:
                 LOGGER.error(
@@ -142,7 +142,7 @@ class APIHandler:
                     method,
                     f"{self.host}{url}",
                 )
-            package_name=None    
+            package_name = None
             if log_config:
                 package_name = log_config.get("package_name", None)
             wkfs_error_details = self.generate_wkfs_error_details(payload, log_entry, response, excp, package_name)
@@ -155,10 +155,10 @@ class APIHandler:
                     method,
                     f"{self.host}{url}",
                 )
-            package_name=None    
+            package_name = None
             if log_config:
                 package_name = log_config.get("package_name", None)
-            #wkfs_error_details = self.generate_wkfs_error_details(payload, log_entry, response, excp, package_name)
+            # wkfs_error_details = self.generate_wkfs_error_details(payload, log_entry, response, excp, package_name)
             exception_message = f"Failed to get success response from WKFS. Received [{excp}] for [{method}]"
 
         raise Exception(f"Exception while connecting to WKFS. Error: {exception_message}")
@@ -167,36 +167,50 @@ class APIHandler:
         response_data = content_uri = transactionIdentifier = None
         if excp.response.text:
             response_data = excp.response.json()
-            transactionIdentifier = response_data.get("generateResultsResponse", {}).get("getGenerateResultsResult", {}).get("transactionIdentifier", None)
+            transactionIdentifier = (
+                response_data.get("generateResultsResponse", {})
+                .get("getGenerateResultsResult", {})
+                .get("transactionIdentifier", None)
+            )
         try:
-            import json    
+            import json
+
             p = json.loads(payload)
             content_uri = p["generate"]["request"]["contentIdentifier"]
         except Exception as e:
             content_uri = None
             pass
-            
+
         additional_details = response_data if response_data else excp
         wkfs_error_details = self.generate_wkfs_exception(
-               form_name=wkfs_package_name,
-               expere_transaction_id=transactionIdentifier if transactionIdentifier else None,
-                content_uri=content_uri if content_uri else None,
-                additional_details=additional_details
-            )
+            form_name=wkfs_package_name,
+            expere_transaction_id=transactionIdentifier if transactionIdentifier else None,
+            content_uri=content_uri if content_uri else None,
+            additional_details=additional_details,
+        )
         if log_entry:
             log_entry.response_code = excp.response.status_code
             log_entry.response_body = response_data
             log_entry.response_time = log_entry.request_time + response.elapsed
             log_entry.save()
         return wkfs_error_details
-        
-    def generate_wkfs_exception(self, customer_name=None, expere_transaction_id=None, form_name=None, content_uri=None, transaction_xml_file_name=None, description=None, additional_details=None):
+
+    def generate_wkfs_exception(
+        self,
+        customer_name=None,
+        expere_transaction_id=None,
+        form_name=None,
+        content_uri=None,
+        transaction_xml_file_name=None,
+        description=None,
+        additional_details=None,
+    ):
         wkfs_error_details = {}
-        wkfs_error_details["customer_name"]=customer_name
-        wkfs_error_details["expere_transaction_id"]=expere_transaction_id
-        wkfs_error_details["form_name"]=form_name
-        wkfs_error_details["content_uri"]=content_uri
-        wkfs_error_details["transaction_xml_file_name"]=transaction_xml_file_name
-        wkfs_error_details["issue_description"]=description
-        wkfs_error_details["additional_details"]=additional_details
-        return wkfs_error_details
\ No newline at end of file
+        wkfs_error_details["customer_name"] = customer_name
+        wkfs_error_details["expere_transaction_id"] = expere_transaction_id
+        wkfs_error_details["form_name"] = form_name
+        wkfs_error_details["content_uri"] = content_uri
+        wkfs_error_details["transaction_xml_file_name"] = transaction_xml_file_name
+        wkfs_error_details["issue_description"] = description
+        wkfs_error_details["additional_details"] = additional_details
+        return wkfs_error_details
